"""Template globals."""

from pprint import pformat
from textwrap import dedent

import emoji
from understory.indieweb.micropub import discover_post_type
from understory.indieweb.webmention import get_mentions
from understory.web import tx

__all__ = ["pformat", "tx", "get_mentions", "discover_post_type", "dedent", "emoji"]



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['canopy', 'canopy.templates']

package_data = \
{'': ['*'], 'canopy': ['static/*'], 'canopy.templates': ['archive/*']}

install_requires = \
['understory>=0.0.40,<0.0.41']

entry_points = \
{'web.apps': ['canopy = canopy:app']}

setup_kwargs = {
    'name': 'canopy-network',
    'version': '0.0.39',
    'description': 'A decentralized social network of personal websites',
    'long_description': '# canopy\nA decentralized social network of personal websites\n\nStore and display content on your own personal website. Interact richly\nwith other sites.\n\n## Install\n\n[Spawn a host](https://gh.ost.lol) and map `canopy-network` to your domain.\n\n### Manually\n\n    $ pip install canopy-network\n    $ web serve canopy\n\n## Features\n\n* render profile, pages, media, posts and feeds with semantic markup a la [microformats](https://indieweb.org/microformats)\n  * archive source material for [reply contexts](https://indieweb.org/reply-context)\n  * moderated threaded discussion using Webmentions with Salmention & Vouch\n  * syndicate to third-party aggregators\n* store posts:\n  * as [queryable JSON](https://www.sqlite.org/json1.html) in SQLite database\n    * [full-text search](https://www.sqlite.org/fts5.html)\n  * as JSON flat files inside Git repository for change history\n* follow by subscribing and publish to subscribers using WebSub\n* sign in to third-party applications using IndieAuth\n  * leverage third-party Micropub editors\n  * leverage third-party Microsub readers\n* import/export tools\n  * syndicate/backfeed to/from Twitter/Github/Facebook\n  * backup/restore to/from local/remote storage\n',
    'author': 'Angelo Gladding',
    'author_email': 'angelo@lahacker.net',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.9,<4.0',
}


setup(**setup_kwargs)



"""A decentralized social network."""

from understory import indieweb, kv, sql, web
from understory.web import tx

app = indieweb.site("Canopy")
templates = web.templates(__name__)


@app.wrap
def template(handler, app):
    """Wrap the response in the final template."""
    yield
    if (
        tx.response.headers.content_type == "text/html"
        and not tx.response.naked
        and tx.host.owner
    ):
        tx.response.body = templates.template(tx.host.owner, tx.response.body)


@app.route(r"settings")
class Settings:
    """."""

    def get(self):
        return templates.settings()

    def post(self):
        form = web.form("theme")
        print(form.theme)
        raise web.SeeOther("/settings")


# @app.route(r"")
# class Home:
#     """."""
#
#     def get(self):
#         """."""
#         return tmpl.home()


# TODO XXX tmpl.about()


# @app.route(r"now")
# class Now:
#     """."""
#
#     def get(self):
#         try:
#             now = tx.pub.read("now")["resource"]
#         except IndexError:
#             tx.pub.create(
#                 "now", mood={"start": [0, 0, 0], "end": [0, 0, 0]}, browsing=[]
#             )
#             now = tx.pub.read("now")["resource"]
#         return tmpl.now(now)
#
#
# @app.route(r"now/peers")
# class NowPeers:
#     """Firehose of peers' /now braids."""
#
#     def subscribe(self):
#         return web.multi_subscribe("alice.com/now", "bob.com/now")
#         # for patch in web.multi_subscribe(*peers):
#         #     yield bytes(f"proxying: {patch.decode()}", "utf-8")


# @app.route(r"{year}")
# class ArchiveYear:
#     """Resources from given year."""
#
#     def get(self):
#         return tmpl.archive.year(self.year, tx.pub.get_year(self.year))
#
#
# @app.route(r"{year}/{month}")
# class ArchiveMonth:
#     """Resources from given month."""
#
#     def get(self):
#         return tmpl.archive.month()
#
#
# @app.route(r"{year}/{month}/{day}")
# class ArchiveDay:
#     """Resources from given day."""
#
#     def get(self):
#         return tmpl.archive.day()
#
#
# @app.route(r"tracks")
# class Tracks:
#     """GPS coords."""
#
#     def post(self):
#         import json
#         import pprint
#
#         pprint.pprint(json.loads(web.form()))


# @app.route(r"{year}/{month}/{day}/{seconds}(/{slug})?")
# class Entry:
#     """An individual entry."""
#
#     def get(self):
#         resource = tx.pub.read(tx.request.uri.path)["resource"]
#         if resource["visibility"] == "private" and not tx.user.session:
#             raise web.Unauthorized(f"/auth?return_to={tx.request.uri.path}")
#         mentions = web.indie.webmention.get_mentions(str(tx.request.uri))
#         return tmpl.entry(resource, mentions)


# @app.route(r"icon-editor")
# class IconEditor:
#     """An icon editor."""
#
#     def get(self):
#         icons = {
#             "bookmark": (
#                 576,
#                 512,
#                 """
#             M 144,32
#             C 136,32 128,40 128,48
#             L 128,480
#             L 288,384
#             L 448,480
#             L 448,48
#             C 448,40 440,32 432,32
#             Z""",
#             )
#         }
#         return tmpl.icon_editor(icons)


# @app.route(r"initialize")
# class Initialize:
#     """."""
#
#     def post(self):
#         uid, passphrase = web.indieauth.init_owner(web.form("name").name)
#         return tmpl.welcome(passphrase)


# app.mount(indieweb.cache_app)
# TODO app.mount(web.debug_app)
# app.mount(indieweb.indieauth.client)
# app.mount(indieweb.indieauth.server)
# app.mount(indieweb.indieauth.root)
# app.mount(indieweb.indieauth.profile)  # NOTE defines the root, should be last
# app.mount(web.micropub.server)
# app.mount(web.microsub.server)
# app.mount(web.webmention.receiver)
# app.mount(web.websub.hub)
# app.mount(web.micropub.content)


# def contextualize(handler, app):
#     """Contextualize this thread based upon the host of the request."""
#     # host = tx.request.uri.host
#     # tx.app.name = host
#     # db = sql.db(f"{host}.db")
#     # db.define("sessions", **web.session_table_sql)
#     # web.add_job_tables(db)
#     # tx.host.db = db
#     # tx.host.cache = web.cache(db=db)
#     # tx.host.kv = kv.db(host, ":", {"jobs": "list"})
#     yield


# app.wrap(web.resume_session)
# app.wrap(indieweb.indieauth.wrap_server)
# app.wrap(indieweb.indieauth.wrap_client)
# app.wrap(web.braidify)


# app.wrap(web.micropub.wrap_server, "post")
# app.wrap(web.webmention.wrap, "post")
# app.wrap(web.microsub.wrap_server, "post")
# app.wrap(web.websub.wrap, "post")
# app.wrap(web.micropub.route_unrouted, "post")
